{ inputs, pkgs, config, lib, ... }: {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
    ../../features/dns-cache.nix
    ../../features/nas0.nix
    ../../features/podman.nix
    ../../features/telemetry/transmission.nix
  ];

  networking.hostName = "seedbox";
  system.stateVersion = "25.05";
  nixpkgs.hostPlatform = "x86_64-linux";

  internal.nas0.useSMB = true;
  internal.nas0.lazyMount = false;

  sops.secrets.protonvpn_username = {};
  sops.secrets.protonvpn_password = {};

  sops.templates."transmission.env" = {
    content = ''
OPENVPN_PROVIDER=PROTONVPN
OPENVPN_CONFIG=mx.protonvpn.udp
OPENVPN_USERNAME=${config.sops.placeholder.protonvpn_username}+pmp
OPENVPN_PASSWORD=${config.sops.placeholder.protonvpn_password}
LOCAL_NETWORK=100.64.0.0/10
'';
  };
  
  virtualisation.oci-containers.containers = {
    torrenty = {
      image = "docker.io/haugene/transmission-openvpn";
      ports = [ "9091:9091" ];
      environmentFiles = [
        config.sops.templates."transmission.env".path
      ];
      volumes = [
        "/mnt/nas0/public/Torrents:/data"
        "/mnt/nas0/public/Movies:/Movies"
        "/mnt/nas0/public/Anime:/Anime"
        "/mnt/nas0/public/AnimeMovies:/AnimeMovies"
        "/mnt/nas0/public/Shows:/Shows"
        "config:/config"
      ];
      extraOptions = [
        "--privileged"
      ];
      autoStart = true;
    };
  };
}
